@@ -22,6 +22,7 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 		self.duration = 0
 		self.position = 0
 
+		self.state = 1
 		self.seedSong = 0
 		self.getStatlist = 0
 		self.getPlaylist = 0
@@ -113,6 +114,7 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 				self.emit(QtCore.SIGNAL("duration"))
 
 	def stateChange( self, state ): #Update backend state change
+		self.state = state
 		if state == 2:
 			self.emit(QtCore.SIGNAL("state(QString)"),"pause")
 		elif state == 1:
@@ -147,9 +149,11 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 		if state == 'pause':
 			self.player.pause()
 		else:
-			self.player.stop()
 			if self.os == "RX-51":
 				self.player.close()
+			else:
+				self.player.stop()
+
 			if self.skip and self.playing:
 				self.onPlayBackEnded()
 	
@@ -157,9 +161,11 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 		self.player.play()
 
 	def onPlayBackEnded( self ): #EOF Reached, start next song.
-		print "EOF called."
-		self.emit(QtCore.SIGNAL("PlayNext"))
-		time.sleep( 2 )
+		if not self.state == 0: #Sometimes when skipping we get an EOF signal, sometimes we don't.  I use this so we don't skip twice.
+			print "EOF called."
+			self.emit(QtCore.SIGNAL("PlayNext"))
+		else:
+			print "Skipped."
 
 	def LoveHate( self ): #Do Love/Hate based on variable settings
 		self.respLH = self.pandora.addFeedback( self.curSong[1]["stationId"], self.curSong, self.loveHateRating )
